==> dcf77pi-3.1.0_1.txz: usr/local/include/dcf77pi/config.h <==
/*
Copyright (c) 2013-2014 René Ladan. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
*/

#ifndef DCF77PI_CONFIG_H
#define DCF77PI_CONFIG_H

/**
 * Read the configuration file and store the values in an internal dictionary.
 *
 * @param filename The name of the configuration file.
 * @return Reading the file is succesful (0), errno or -1 otherwise.
 */
int read_config_file(char *filename);

/**
 * Rerieve a configuration value from the internal dictionary.
 *
 * @param keyword: the key for the value to retrieve. Valid keys are:
 * "pin", "activehigh", "freq", "summermonth", "wintermonth",
 * "leapsecmonths", "outlogfile"
 * @return The corresponding value, or NULL when the key was not found.
 */
char *get_config_value(char *keyword);

#endif

==> dcf77pi-3.5.0.txz: usr/local/include/dcf77pi/config.h <==
/*
Copyright (c) 2013-2014 René Ladan. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
*/

#ifndef DCF77PI_CONFIG_H
#define DCF77PI_CONFIG_H

/**
 * Read the configuration file and store the values in an internal dictionary.
 *
 * @param filename The name of the configuration file.
 * @return Reading the file is succesful (0), errno or -1 otherwise.
 */
int read_config_file(const char * const filename);

/**
 * Rerieve a configuration value from the internal dictionary.
 *
 * @param keyword: the key for the value to retrieve. Valid keys are:
 *   "pin", "iodev", "activehigh", "freq", "summermonth", "wintermonth",
 *   "leapsecmonths", "outlogfile"
 * @return The corresponding value, or NULL when the key was not found.
 */
/*@null@*/char *get_config_value(const char * const keyword);

#endif
